# Subsampling dual-comb spectroscopy

This code is intended to demonstrate the algorithm described in "Subsampling dual-comb spectroscopy" by L. A. Sterczewski & M. Bagheri. The algorithm relies on sampling well below the Nyquist frequency to compress spectral information of the sparse dual-comb signal. 

## How to run 

This package provides two simulation scenarios - real and synthetic data. 

#### Synthetic data case
The `SubsamplingSyntheticData` directory contains, as the name says, files used in the simulation of synthetic dual-comb signals. There are three possible variants of subsampling supported.

1. Subsampling in the `F_S+` variant -- `combSimulator_F_Splus_demo.m`.
2. Subsampling in the `F_S-` variant -- `combSimulator_F_Sminus_demo.m`.
3. Subsampling without changing the shape (like in DCS) -- `combSimulator_F_S_likeDCS_demo.m`.

Please see the paper for explanation of the above terms. File `subsamplingAnalysis.m` shall not be used by itself. Please run `combSimulator.m` instead.

#### Real data case

The real data case is stored in `SubsamplingRealData`. File `subsampleRealData.m` resamples the input signal stored in .mat format to a new frequency for decimation. Subsampling is performed in a phase-shifted fashion (polyphase decomposition) to demonstrate the feasibility coherent integration. This allows to enhance the vertical resolution improve the signal-to-noise ratio.

File `ICL_DCS_harmonic` stored in .mat format in `data` directory was recorded from a self-contained dual-comb spectrometer described in "Mid-infrared dual-comb spectroscopy with room-temperature bi-functional interband cascade lasers and detectors" by Sterczewski et al. (2020).

## Prerequisites

Matlab with the `signal_toolbox` module is required to execute `finddelay`, `downsample` and `pwelch` functions. The code was tested on version R2018b but in principle it should work on any recent version. It is however possible to modify the code to rely on the basic Matlab functions without proprietary toolboxes.

## Funding
National Aeronautics and Space Agency’s (NASA) PICASSO program (106822 / 811073.02.24.01.85);  Universities Space Research Association (USRA), NASA Postdoctoral Program (NPP).

## Acknowledgements
This work was supported under and was in part performed at the Jet Propulsion Laboratory (JPL), California Institute of Technology, under contract with the NASA. L. A. Sterczewski’s research was supported by an appointment to the NASA Postdoctoral Program at JPL, administered by Universities Space Research Association under contract with NASA. The authors would like to thank Dr. Jerry Meyer and Dr. Igor Vurgaftman at NRL, and Dr. Clifford Frez at JPL for providing the interband cascade laser (ICL) material used in for acquiring real spectroscopic data provided here.