% Author: Lukasz A. Sterczewski, Ph.D.
% NASA Jet Propulsion Laboratory, California Institute of Technology
% email address: lukasz.a.sterczewski@jpl.nasa.gov 
% March 2020; Last revision: 24-March-2020

% This code is intended to demonstrate the algorithm described in 
% "Subsampling Dual-Comb Spectroscopy" by L. A. Sterczewski & M. Bagheri 

% It generates a synthetic dual-comb spectrum with $n$ lines 
% and subsamples it through sample decimation. The unaliased signal sampling  
% rate is picked only from a decimation standpoint. 

% This is a parent script. Use it to provide simulation parameters and run
% the plotting routine.

% Funding: National Aeronautics and Space Agencys (NASA) PICASSO program 
% (106822 / 811073.02.24.01.85);  Universities Space Research Association
% (USRA), NASA Postdoctoral Program (NPP). 

% Acknowledgement: This work was supported under and was in part performed 
% at the Jet Propulsion Laboratory (JPL), California Institute of Technology,
% under contract with the NASA. L. A. Sterczewskis % research was supported 
% by an appointment to the NASA Postdoctoral Program % at JPL, administered 
% by Universities Space Research Association under contract with NASA. 

clear all;
close all;
clc;

addpath('.././pathfcns');
addpath('.././pathfcns/cbrewer');
exportFontSize = 12;

saveFigures = false; %set to true if figure files are to be saved

%% Signal parameters - user input

M = 23; %decimation factor
deltaF_r = 22.964 * 10^6; %Hz, comb repetition difference

nCombLines = 23; % number of comb lines
nIfgSamples = 1*10^5; %number of samples in the dcs interferogram

subsamplingVariant = 'plus'; %can be 'plus', 'minus', or 'likedcs'

%% Run analysis
subsamplingAnalysis;